Welcome to TurboGears 2.0, standing on the shoulders of giants, since 2007

${sidebar_top()}

## Presentation

TurboGears 2 is rapid web application development toolkit designed to make your life easier.

1. ### Code your data model

   Design your data model, Create the database, and Add some bootstrap data.

2. ### Design your URL architecture

   Decide your URLs, Program your controller methods, Design your templates, and place some static files (CSS and/or JavaScript).

3. ### Distribute your app

   Test your source, Generate project documents, Build a distribution.

Thank you for choosing TurboGears.